struct ImageRequest {
inner: ImageLoaderRequest,
priority: ImageRequestPriority,
result_sender: Sender<Result<Image, ImageError>>,
retries_count: u8,
task_handle: Arc<Mutex<Option<JoinHandle<()>>>>,
stalled_timeout_source: Arc<Mutex<Option<SourceId>>>,
}Expand description
A request for an image.
Fields
inner: ImageLoaderRequestThe request to the image loader.
priority: ImageRequestPriorityThe priority of the request.
result_sender: Sender<Result<Image, ImageError>>The sender of the channel to use to send the result.
retries_count: u8The number of retries for this request.
task_handle: Arc<Mutex<Option<JoinHandle<()>>>>The handle for aborting the current task of this request.
stalled_timeout_source: Arc<Mutex<Option<SourceId>>>The timeout source for marking this request as stalled.
Implementations
Sourceimpl ImageRequest
impl ImageRequest
Sourcefn new(
inner: ImageLoaderRequest,
priority: ImageRequestPriority,
) -> (Self, Receiver<Result<Image, ImageError>>)
fn new( inner: ImageLoaderRequest, priority: ImageRequestPriority, ) -> (Self, Receiver<Result<Image, ImageError>>)
Construct an image request with the given data and priority.
Sourcefn can_retry(retries_count: u8, error: ImageError) -> bool
fn can_retry(retries_count: u8, error: ImageError) -> bool
Whether we can retry a request with the given retries count and after the given error.